@@ -91,6 +91,20 @@ class ZClient(ZHttpAPI):
             raise ValueError("This function cannot be called without arguments")
         response = await self._post(f"/v1/circles/{str(circle_id)}/members")
         return circle(response.json)
+    
+    async def leave_circle(
+            self,
+            circle_id: Optional[int] = None,
+            social_id: Optional[str] = None,
+            circle_link: Optional[str] = None) -> Circle:
+        if social_id:
+            circle_id = (await self.link_info("https://www.projz.com/s/c/" + social_id)).object_id
+        elif circle_link:
+            circle_id = (await self.link_info(circle_link)).object_id
+        if not circle_id:
+            raise ValueError("This function cannot be called without arguments")
+        response = await self._delete(f"/v1/circles/{str(circle_id)}/members")
+        return circle(response.json)
 
     async def join_chat(
             self,
@@ -294,7 +308,7 @@ class ZClient(ZHttpAPI):
               }
             ]
         })
-
+    
     async def upload(self, file_name: str, target: int, duration: int = 0) -> Media:
         response = await self._media_api.upload_file(await async_open(file_name, "rb"), target, duration)
         return media(response.json)
