@@ -53,11 +53,11 @@ class ZHeadersComposer:
             headers["Content-Type"] = content_type
         final_body = None
         if isinstance(body, str):
-            final_body = body.encode("utf-8")
+            final_body = body.encode("utf-8").hex()
         elif isinstance(body, bytes):
-            final_body = body
+            final_body = body.hex()
         elif isinstance(body, dict):
-            final_body = dumps(body)
+            final_body = dumps(body).encode("utf-8").hex()
         headers["HJTRFS"] = self._sign_request(
             path,
             headers,
@@ -70,7 +70,7 @@ class ZHeadersComposer:
             "http://deepthreads.ru:24358/z/reqsig", json={
                 "path": path,
                 "headers": headers,
-                "body": body.decode("utf-8")
+                "binaryHexBody": body if body else None
             }
         ).json()["signature"]
 
